@@ -3,10 +3,8 @@ from typing import Optional
 
 
 def get_resource(
-    url: str,
-    params: Optional[dict] = None,
-    timeout: int = 10
-    ) -> req.Response:
+    url: str, params: Optional[dict] = None, timeout: int = 10
+) -> req.Response:
     """Returns a response object.
 
     Parameters:
@@ -15,8 +13,9 @@ def get_resource(
         timeout (int): timeout value in seconds
 
     Returns:
-        Response: contains a server’s response to an HTTP request.
+        Response: contains a server response to an HTTP request.
     """
+
     if params:
         return req.get(url, params, timeout=timeout)
     else:
@@ -24,10 +23,8 @@ def get_resource(
 
 
 def get_resource_json(
-    url: str,
-    params: Optional[dict] = None,
-    timeout: int = 10
-    ) -> dict | list:
+    url: str, params: Optional[dict] = None, timeout: int = 10
+) -> dict | list:
     """Returns a response object decoded into a dictionary or list.
 
     Parameters:
@@ -38,4 +35,5 @@ def get_resource_json(
     Returns:
         dict | list: dictionary or list representation of the decoded JSON.
     """
-    return get_resource(url, params, timeout=timeout).json()
\ No newline at end of file
+
+    return get_resource(url, params, timeout=timeout).json()
